pub enum InterimError<O: Error> {
Recognized(Box<dyn Problem>),
Unidentified {
retcode: i32,
lines: Vec<String>,
secondary: Option<Box<dyn Match>>,
},
Other(O),
}Expand description
Intermediate error type used during build fixing.
This enum represents different kinds of errors that can occur during the build process, and which may be fixable by a BuildFixer.
Variants
Recognized(Box<dyn Problem>)
A problem that was detected during the build, and that we can attempt to fix.
Unidentified
An error that we could not identify.
Fields
Other(O)
Another error raised specifically by the callback function that is not fixable.