pub enum Error {
UnknownDependencyFamily,
UnsupportedScope(InstallationScope),
UnsupportedScopes(Vec<InstallationScope>),
AnalyzedError(AnalyzedError),
SessionError(Error),
Other(String),
}Expand description
Errors that can occur during dependency installation.
Variants
UnknownDependencyFamily
Error indicating that the dependency family is unknown.
UnsupportedScope(InstallationScope)
Error indicating that the requested installation scope is not supported.
UnsupportedScopes(Vec<InstallationScope>)
Error indicating that the requested installation scopes are not supported.
AnalyzedError(AnalyzedError)
Error from analyzing a command execution.
SessionError(Error)
Error from the session.
Other(String)
Other error with a message.