pub enum Error {
CalledProcessError(ExitStatus),
IoError(Error),
SetupFailure(String, String),
ImageError(ImageError),
}Expand description
Errors that can occur in a session.
Variants
CalledProcessError(ExitStatus)
Error caused by a command that exited with a non-zero status code.
IoError(Error)
Error from an IO operation.
SetupFailure(String, String)
Error from setting up the session, with a message and detailed description.
ImageError(ImageError)
Error from image operations (download, cache, etc.)